tags 642686 patch
thanks
Hi,
I've tried to fix this FTBFS issue by adjusting Java path.
Please check attached patch, thanks.
--
Regards,
Hideki Yamane henrich @ debian.or.jp/org
http://wiki.debian.org/HidekiYamane
diff -Nru javamorph-0.0.20100201/JavaMorph.xpm javamorph-0.0.20100201/JavaMorph.xpm
--- javamorph-0.0.20100201/JavaMorph.xpm 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/JavaMorph.xpm 1970-01-01 09:00:00.000000000 +0900
@@ -1,38 +0,0 @@
-/* XPM */
-static char * JavaMorph_xpm[] = {
-"32 32 3 1",
-" c #381AF1",
-". c #FFF043",
-"+ c #391BF1",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-"................................",
-"................................",
-"................................",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-"................................",
-"................................",
-"................................",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-" ... ... ",
-"+ ... ... "};
diff -Nru javamorph-0.0.20100201/MANIFEST.MF javamorph-0.0.20100201/MANIFEST.MF
--- javamorph-0.0.20100201/MANIFEST.MF 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/MANIFEST.MF 1970-01-01 09:00:00.000000000 +0900
@@ -1,3 +0,0 @@
-Manifest-Version: 1.0
-Main-Class: javamorph.CMain
-
diff -Nru javamorph-0.0.20100201/Makefile javamorph-0.0.20100201/Makefile
--- javamorph-0.0.20100201/Makefile 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/Makefile 1970-01-01 09:00:00.000000000 +0900
@@ -1,25 +0,0 @@
-# JavaMorph - Film industry image merging program's MAKEFILE.
-
-JAVA = /usr/lib/jvm/java-6-openjdk/bin/
-CONT = input javamorph/*.class mesh polygon JavaMorph.png
-
-install:
- install -m 644 -D javamorph.jar ${DESTDIR}/usr/share/javamorph/javamorph.jar
- install -m 644 -D JavaMorph.png ${DESTDIR}/usr/share/pixmaps/JavaMorph.png
- install -m 644 -D JavaMorph.xpm ${DESTDIR}/usr/share/pixmaps/JavaMorph.xpm
- install -m 755 -D help/javamorph ${DESTDIR}/usr/bin/javamorph
- install -m 644 -D help/JavaMorph.pdf ${DESTDIR}/usr/share/doc/javamorph/JavaMorph.pdf
- install -m 644 -D changelog ${DESTDIR}/usr/share/doc/javamorph/changelog.gz
- install -m 644 -D javamorph.desktop ${DESTDIR}/usr/share/applications/javamorph.desktop
- install -m 644 -D javamorph.1 ${DESTDIR}/usr/share/man/man1/javamorph.1
-
-build:
- ${JAVA}jar -cmf MANIFEST.MF javamorph.jar ${CONT}
-
-compile:
- ${JAVA}javac -d . javamorph/*.java
-
-clean:
- rm -fR javamorph/*.class
- rm -f javamorph.jar
-
diff -Nru javamorph-0.0.20100201/changelog javamorph-0.0.20100201/changelog
--- javamorph-0.0.20100201/changelog 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/changelog 1970-01-01 09:00:00.000000000 +0900
@@ -1,15 +0,0 @@
-+ UPSTREAM CHANGELOG 2009-01-11 [email protected]
-==================================================================
-
-+ Source proviced combined with the binary => Classes and Javadoc removed.
-+ Paths adopted (for example Workdir in $HOME).
-+ Number of Java Runtimes limited.
-+ OPENJDK has a slower GUI (POINTERDRAG).
-+ GCJ dosn't calculate very fast.
-+ PDF viewer necessary to view the help file.
-
-+ UPSTREAM CHANGELOG 2010-02-02 [email protected]
-==================================================================
-
-+ COPYING file added and GPLv2 reference anchored.
-
diff -Nru javamorph-0.0.20100201/debian/changelog javamorph-0.0.20100201/debian/changelog
--- javamorph-0.0.20100201/debian/changelog 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/debian/changelog 2012-01-04 21:36:38.000000000 +0900
@@ -1,3 +1,15 @@
+javamorph (0.0.20100201-1.1) unstable; urgency=low
+
+ * Non-maintainer upload.
+ * debian/source/format
+ - set "3.0 (quilt)" to handle patches
+ * debian/patches
+ - add package-modified.patch to handle changes that applied directly
+ in previous revision
+ - add Makefile.patch to adjust Java path (Closes: #642686)
+
+ -- Hideki Yamane <[email protected]> Wed, 04 Jan 2012 21:35:16 +0900
+
javamorph (0.0.20100201-1) unstable; urgency=low
[ Claus Wimmer ]
diff -Nru javamorph-0.0.20100201/debian/patches/Makefile.patch javamorph-0.0.20100201/debian/patches/Makefile.patch
--- javamorph-0.0.20100201/debian/patches/Makefile.patch 1970-01-01 09:00:00.000000000 +0900
+++ javamorph-0.0.20100201/debian/patches/Makefile.patch 2012-01-04 21:37:40.000000000 +0900
@@ -0,0 +1,13 @@
+Index: javamorph-0.0.20100201/Makefile
+===================================================================
+--- javamorph-0.0.20100201.orig/Makefile 2012-01-04 21:36:42.124465086 +0900
++++ javamorph-0.0.20100201/Makefile 2012-01-04 21:37:37.536509466 +0900
+@@ -1,6 +1,7 @@
+ # JavaMorph - Film industry image merging program's MAKEFILE.
+
+-JAVA = /usr/lib/jvm/java-6-openjdk/bin/
++DEB_BUILD_ARCH = $(shell dpkg-architecture -qDEB_BUILD_ARCH)
++JAVA = /usr/lib/jvm/java-6-openjdk-$(DEB_BUILD_ARCH)/bin/
+ CONT = input javamorph/*.class mesh polygon JavaMorph.png
+
+ install:
diff -Nru javamorph-0.0.20100201/debian/patches/package_modified.patch javamorph-0.0.20100201/debian/patches/package_modified.patch
--- javamorph-0.0.20100201/debian/patches/package_modified.patch 1970-01-01 09:00:00.000000000 +0900
+++ javamorph-0.0.20100201/debian/patches/package_modified.patch 2012-01-04 21:39:05.000000000 +0900
@@ -0,0 +1,356 @@
+Index: javamorph-0.0.20100201/JavaMorph.xpm
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/JavaMorph.xpm 2012-01-04 21:36:42.120465083 +0900
+@@ -0,0 +1,38 @@
++/* XPM */
++static char * JavaMorph_xpm[] = {
++"32 32 3 1",
++" c #381AF1",
++". c #FFF043",
++"+ c #391BF1",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++"................................",
++"................................",
++"................................",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++"................................",
++"................................",
++"................................",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++" ... ... ",
++"+ ... ... "};
+Index: javamorph-0.0.20100201/Makefile
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/Makefile 2012-01-04 21:38:45.604564260 +0900
+@@ -0,0 +1,25 @@
++# JavaMorph - Film industry image merging program's MAKEFILE.
++
++JAVA = /usr/lib/jvm/java-6-openjdk/bin/
++CONT = input javamorph/*.class mesh polygon JavaMorph.png
++
++install:
++ install -m 644 -D javamorph.jar ${DESTDIR}/usr/share/javamorph/javamorph.jar
++ install -m 644 -D JavaMorph.png ${DESTDIR}/usr/share/pixmaps/JavaMorph.png
++ install -m 644 -D JavaMorph.xpm ${DESTDIR}/usr/share/pixmaps/JavaMorph.xpm
++ install -m 755 -D help/javamorph ${DESTDIR}/usr/bin/javamorph
++ install -m 644 -D help/JavaMorph.pdf ${DESTDIR}/usr/share/doc/javamorph/JavaMorph.pdf
++ install -m 644 -D changelog ${DESTDIR}/usr/share/doc/javamorph/changelog.gz
++ install -m 644 -D javamorph.desktop ${DESTDIR}/usr/share/applications/javamorph.desktop
++ install -m 644 -D javamorph.1 ${DESTDIR}/usr/share/man/man1/javamorph.1
++
++build:
++ ${JAVA}jar -cmf MANIFEST.MF javamorph.jar ${CONT}
++
++compile:
++ ${JAVA}javac -d . javamorph/*.java
++
++clean:
++ rm -fR javamorph/*.class
++ rm -f javamorph.jar
++
+Index: javamorph-0.0.20100201/changelog
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/changelog 2012-01-04 21:36:42.124465086 +0900
+@@ -0,0 +1,15 @@
+++ UPSTREAM CHANGELOG 2009-01-11 [email protected]
++==================================================================
++
+++ Source proviced combined with the binary => Classes and Javadoc removed.
+++ Paths adopted (for example Workdir in $HOME).
+++ Number of Java Runtimes limited.
+++ OPENJDK has a slower GUI (POINTERDRAG).
+++ GCJ dosn't calculate very fast.
+++ PDF viewer necessary to view the help file.
++
+++ UPSTREAM CHANGELOG 2010-02-02 [email protected]
++==================================================================
++
+++ COPYING file added and GPLv2 reference anchored.
++
+Index: javamorph-0.0.20100201/help/javamorph
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/help/javamorph 2012-01-04 21:36:42.124465086 +0900
+@@ -0,0 +1,47 @@
++#!/bin/bash
++
++# Start JavaMorph - Morphing Program.
++
++# Contains all help files.
++HELPDIR="/usr/share/doc/javamorph/"
++# Tutorial PDF.
++HELPFILE=${HELPDIR}JavaMorph.pdf.gz
++# Pass DEBIAN specific help file locations to the JVM.
++OPTS="-DHELPDIR=${HELPDIR} -DHELPFILE=${HELPFILE}"
++# Location of the OPENJDK JVM.
++J_OPEN="/usr/lib/jvm/java-6-openjdk/jre/bin/java"
++# Location of the GCJ JVM.
++J_GCJ="/usr/lib/jvm/java-gcj/jre/bin/java"
++# Choose the JVM if installed.
++if test -a ${J_GCJ}
++then
++ JAVA=${J_GCJ}
++ echo I take GCJ-1.5.0.
++else
++ if test -a ${J_OPEN}
++ then
++ JAVA=${J_OPEN}
++ echo I take OPENJDK-6.
++ else
++ # Stop if no JVM is installed.
++ echo "ERROR: No Java VM found for JavaMorph!"
++ exit 1
++ fi
++fi
++# Choose the helpviewer.
++if test -a /usr/bin/evince
++then
++ HELPVIEW=/usr/bin/evince
++else
++ if test -a /usr/bin/okular
++ then
++ HELPVIEW=/usr/bin/okular
++ else
++ echo "WARNING: Help viewer not found!"
++ fi
++fi
++# Start the JavaMorph program.
++${JAVA} ${OPTS} -DHELPVIEW=${HELPVIEW} -jar /usr/share/javamorph/javamorph.jar
++# Say good bye.
++echo "Open me again if I'm good or report bugs otherwise! Bye ..."
++
+Index: javamorph-0.0.20100201/javamorph.1
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/javamorph.1 2012-01-04 21:36:42.124465086 +0900
+@@ -0,0 +1,42 @@
++.\" Hey, EMACS: -*- nroff -*-
++.\" First parameter, NAME, should be all caps
++.\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
++.\" other parameters are allowed: see man(7), man(1)
++.TH "JAVAMORPH" "1" "January 9, 2010"
++.\" Please adjust this date whenever revising the manpage.
++.\"
++.\" Some roff macros, for reference:
++.\" .nh disable hyphenation
++.\" .hy enable hyphenation
++.\" .ad l left justify
++.\" .ad b justify to both left and right margins
++.\" .nf disable filling
++.\" .fi enable filling
++.\" .br insert line break
++.\" .sp <n> insert n+1 empty lines
++.\" for manpage-specific macros, see man(7)
++.SH NAME
++javamorph \- Make a morphing film between two pictures of human faces (GUI).
++.SH SYNOPSIS
++.B javamorph
++.SH DESCRIPTION
++\fBjavamorph\fP merges its two input pictures to a film-like sequence of
++bitmaps where the left picture morphs to the right one. Feel free to convert
++the picture sequence into a MPEG stream by using tools like MENCODER! Morphing
++is done by this program in a half automatic way, the user has to mark
++characteristic regions by points.
++.SH OPTIONS
++This program doesn't have any command line options.
++.SH SEE ALSO
++\fBgimp\fP, \fBmplayer\fP, \fBjava\fP
++.br
++.SH FILES
++Help: \fB/usr/share/doc/javamorph/JavaMorph.pdf\fP
++.br
++Workdir: \fB$HOME/JavaMorph/\fP
++.SH AUTHOR
++javamorph was written by Claus Wimmer <[email protected]>.
++.PP
++This manual page was written by Claus Wimmer <[email protected]>,
++for the Debian project (and may be used by others).
++
+Index: javamorph-0.0.20100201/javamorph.desktop
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/javamorph.desktop 2012-01-04 21:36:42.124465086 +0900
+@@ -0,0 +1,11 @@
++[Desktop Entry]
++Version=0.0
++Name=JavaMorph
++Exec=/usr/bin/javamorph
++Terminal=false
++Icon=/usr/share/pixmaps/JavaMorph.xpm
++Type=Application
++MimeType=application/x-javamorph
++Categories=Graphics;
++GenericName=JavaMorph
++Comment=Merge two human-face-JPEGs!
+Index: javamorph-0.0.20100201/javamorph/CAbout.java
+===================================================================
+--- javamorph-0.0.20100201.orig/javamorph/CAbout.java 2012-01-04 21:35:06.308388825 +0900
++++ javamorph-0.0.20100201/javamorph/CAbout.java 2012-01-04 21:36:42.124465086 +0900
+@@ -99,10 +99,9 @@
+ g.setFont(new Font("Sans Serif", Font.BOLD, 10));
+ g.drawString("Home: " + CStrings.HOME, 20, 170);
+ g.drawString
+- ("Work: " + "Home" + CStrings.SEP + CStrings.APPDIR, 20, 190);
++ ("Work: " + "$HOME" + CStrings.SEP + CStrings.APPDIR, 20, 190);
+ g.drawString
+- ("Hint: Find a tutorial within the help subdir of the workdir."
+- , 20, 210);
++ ("Hint: Find a tutorial in " + CStrings.HELPDIR + "." , 20, 210);
+ }
+ /**
+ * Satisfy the java API.
+Index: javamorph-0.0.20100201/javamorph/CMain.java
+===================================================================
+--- javamorph-0.0.20100201.orig/javamorph/CMain.java 2012-01-04 21:35:06.292388813 +0900
++++ javamorph-0.0.20100201/javamorph/CMain.java 2012-01-04 21:36:42.124465086 +0900
+@@ -109,7 +109,7 @@
+ /* Start program. */
+ CMain prog = new CMain();
+ /* Debug program info. */
+- System.out.println("Main class = " +prog + '.');
++ System.out.println("Main class = " + prog + '.');
+ }
+ }
+ /**
+Index: javamorph-0.0.20100201/javamorph/CPopupMenuDecorator.java
+===================================================================
+--- javamorph-0.0.20100201.orig/javamorph/CPopupMenuDecorator.java 2012-01-04 21:35:06.300388819 +0900
++++ javamorph-0.0.20100201/javamorph/CPopupMenuDecorator.java 2012-01-04 21:36:42.124465086 +0900
+@@ -95,8 +95,10 @@
+ new JRadioButtonMenuItem("Edit polygon.");
+ /** Edit configuration command. */
+ private JMenuItem m_edit_config = new JMenuItem("Edit Config ->");
++ /** Open the help PDF viewer. */
++ private JMenuItem m_help = new JMenuItem("Help?");
+ /** Show about box command. */
+- private JMenuItem m_about = new JMenuItem("Help about?");
++ private JMenuItem m_about = new JMenuItem("About?");
+ /**
+ * Constructor.
+ * @param parent The parent JComponent to draw the mouse symbol to.
+@@ -113,6 +115,7 @@
+ popup_menu.add(this.mesh_menu);
+ popup_menu.add(this.polygon_menu);
+ popup_menu.addSeparator();
++ popup_menu.add(m_help);
+ popup_menu.add(m_about);
+ mesh_menu.add(m_add_mesh_points);
+ mesh_menu.add(m_sub_mesh_points);
+@@ -143,6 +146,7 @@
+ m_sub_polygon_points.addActionListener(this);
+ m_off_polygon_points.addActionListener(this);
+ m_delete_polygon.addActionListener(this);
++ m_help.addActionListener(this);
+ m_about.addActionListener(this);
+ parent.addMouseListener(this);
+ }
+@@ -226,10 +230,24 @@
+ if(m_edit_config == e.getSource()){
+ parent.getParent().showConfigDialog();
+ }
++ if(m_help == e.getSource()){
++ try{
++ String cmd =
++ System.getProperty("HELPVIEW") +
++ ' ' +
++ System.getProperty("HELPFILE");
++ System.out.println("Try call " + cmd + ' ');
++ Runtime.getRuntime().exec(cmd);
++ }catch(Exception x){
++ JOptionPane.showMessageDialog
++ (parent, "Helpfile missing. Download \"JavaMorph.pdf!\"");
++ System.out.println(x.getMessage());
++ x.printStackTrace();
++ }
++ }
+ if(m_about == e.getSource()){
+ parent.getParent().showAboutDialog();
+ }
+-
+ if(m_add_mesh_points == e.getSource()){
+ CConfig.edit_state = CConfig.EDIT_MESH_ADD;
+ }
+Index: javamorph-0.0.20100201/javamorph/CStrings.java
+===================================================================
+--- javamorph-0.0.20100201.orig/javamorph/CStrings.java 2012-01-04 21:35:06.320388835 +0900
++++ javamorph-0.0.20100201/javamorph/CStrings.java 2012-01-04 21:36:42.124465086 +0900
+@@ -44,7 +44,7 @@
+ /** Dir from which this application has been started. */
+ public static final String DIR = System.getProperty("user.dir");
+ /** Location of the .jar distribution file. */
+- public static final String JAR = DIR + SEP + "JavaMorph_2009_01_19.jar";
++ public static final String JAR = DIR + SEP + "JavaMorph_2010_02_01.jar";
+ /** Program name. */
+ public static final String PROG = "JavaMorph";
+ /** Program version. */
+@@ -54,15 +54,13 @@
+ /** License description. */
+ public static final String LICENSE = "GPLv2";
+ /** Working directory name. */
+- public static final String APPDIR = "Desktop" + SEP + PROG + SEP;
++ public static final String APPDIR = PROG + SEP;
+ /** Working directory path. */
+ public static final String WORKDIR = HOME + APPDIR;
+ /** Input directory path. */
+ public static final String INPUTDIR = HOME + APPDIR + "input" + SEP;
+ /** Debug directory path. */
+ public static final String DEBUGDIR = HOME + APPDIR + "debug" + SEP;
+- /** Help directory path. */
+- public static final String HELPDIR = HOME + APPDIR + "help" + SEP;
+ /** Polygon data directory path. */
+ public static final String POLYGONDIR = HOME + APPDIR + "polygon" + SEP;
+ /** Mesh data directory path. */
+@@ -87,10 +85,8 @@
+ public static final String LEFT_DEBUG = DEBUGDIR + "left_debug.png";
+ /** Right clip matrix file name & path. */
+ public static final String RIGHT_DEBUG = DEBUGDIR + "right_debug.png";
+- /** Copyright file name & path. */
+- public static final String COPYING = HELPDIR + "COPYING";
+- /** Help file name & path. */
+- public static final String HELP = HELPDIR + "JavaMorph.pdf";
++ /** Help directory path. */
++ public static final String HELPDIR = System.getProperty("HELPDIR");
+ /** File to store the triangulation of the left mesh to. */
+ public static final String LEFT_TRI = DEBUGDIR + "t_left_triangles.png";
+ /** File to store the triangulation of the right mesh to. */
+@@ -167,8 +163,6 @@
+ * sub directories of the working directory.
+ */
+ public static void extractFiles(){
+- copyFile("help/COPYING", COPYING);
+- copyFile("help/JavaMorph.pdf", HELP);
+ copyFile("input/left.jpg", LEFT_INPUT);
+ copyFile("input/right.jpg", RIGHT_INPUT);
+ copyFile("mesh/left.msh", LEFT_MESH);
+Index: javamorph-0.0.20100201/MANIFEST.MF
+===================================================================
+--- /dev/null 1970-01-01 00:00:00.000000000 +0000
++++ javamorph-0.0.20100201/MANIFEST.MF 2012-01-04 21:34:42.068368575 +0900
+@@ -0,0 +1,3 @@
++Manifest-Version: 1.0
++Main-Class: javamorph.CMain
++
diff -Nru javamorph-0.0.20100201/debian/patches/series javamorph-0.0.20100201/debian/patches/series
--- javamorph-0.0.20100201/debian/patches/series 1970-01-01 09:00:00.000000000 +0900
+++ javamorph-0.0.20100201/debian/patches/series 2012-01-04 21:36:48.000000000 +0900
@@ -0,0 +1,2 @@
+package_modified.patch
+Makefile.patch
diff -Nru javamorph-0.0.20100201/debian/source/format javamorph-0.0.20100201/debian/source/format
--- javamorph-0.0.20100201/debian/source/format 1970-01-01 09:00:00.000000000 +0900
+++ javamorph-0.0.20100201/debian/source/format 2012-01-04 21:33:39.000000000 +0900
@@ -0,0 +1 @@
+3.0 (quilt)
diff -Nru javamorph-0.0.20100201/help/javamorph javamorph-0.0.20100201/help/javamorph
--- javamorph-0.0.20100201/help/javamorph 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/help/javamorph 1970-01-01 09:00:00.000000000 +0900
@@ -1,47 +0,0 @@
-#!/bin/bash
-
-# Start JavaMorph - Morphing Program.
-
-# Contains all help files.
-HELPDIR="/usr/share/doc/javamorph/"
-# Tutorial PDF.
-HELPFILE=${HELPDIR}JavaMorph.pdf.gz
-# Pass DEBIAN specific help file locations to the JVM.
-OPTS="-DHELPDIR=${HELPDIR} -DHELPFILE=${HELPFILE}"
-# Location of the OPENJDK JVM.
-J_OPEN="/usr/lib/jvm/java-6-openjdk/jre/bin/java"
-# Location of the GCJ JVM.
-J_GCJ="/usr/lib/jvm/java-gcj/jre/bin/java"
-# Choose the JVM if installed.
-if test -a ${J_GCJ}
-then
- JAVA=${J_GCJ}
- echo I take GCJ-1.5.0.
-else
- if test -a ${J_OPEN}
- then
- JAVA=${J_OPEN}
- echo I take OPENJDK-6.
- else
- # Stop if no JVM is installed.
- echo "ERROR: No Java VM found for JavaMorph!"
- exit 1
- fi
-fi
-# Choose the helpviewer.
-if test -a /usr/bin/evince
-then
- HELPVIEW=/usr/bin/evince
-else
- if test -a /usr/bin/okular
- then
- HELPVIEW=/usr/bin/okular
- else
- echo "WARNING: Help viewer not found!"
- fi
-fi
-# Start the JavaMorph program.
-${JAVA} ${OPTS} -DHELPVIEW=${HELPVIEW} -jar /usr/share/javamorph/javamorph.jar
-# Say good bye.
-echo "Open me again if I'm good or report bugs otherwise! Bye ..."
-
diff -Nru javamorph-0.0.20100201/javamorph/CAbout.java javamorph-0.0.20100201/javamorph/CAbout.java
--- javamorph-0.0.20100201/javamorph/CAbout.java 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/javamorph/CAbout.java 2010-02-01 23:06:44.000000000 +0900
@@ -99,9 +99,10 @@
g.setFont(new Font("Sans Serif", Font.BOLD, 10));
g.drawString("Home: " + CStrings.HOME, 20, 170);
g.drawString
- ("Work: " + "$HOME" + CStrings.SEP + CStrings.APPDIR, 20, 190);
+ ("Work: " + "Home" + CStrings.SEP + CStrings.APPDIR, 20, 190);
g.drawString
- ("Hint: Find a tutorial in " + CStrings.HELPDIR + "." , 20, 210);
+ ("Hint: Find a tutorial within the help subdir of the workdir."
+ , 20, 210);
}
/**
* Satisfy the java API.
diff -Nru javamorph-0.0.20100201/javamorph/CMain.java javamorph-0.0.20100201/javamorph/CMain.java
--- javamorph-0.0.20100201/javamorph/CMain.java 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/javamorph/CMain.java 2010-02-01 23:13:20.000000000 +0900
@@ -109,7 +109,7 @@
/* Start program. */
CMain prog = new CMain();
/* Debug program info. */
- System.out.println("Main class = " + prog + '.');
+ System.out.println("Main class = " +prog + '.');
}
}
/**
diff -Nru javamorph-0.0.20100201/javamorph/CPopupMenuDecorator.java javamorph-0.0.20100201/javamorph/CPopupMenuDecorator.java
--- javamorph-0.0.20100201/javamorph/CPopupMenuDecorator.java 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/javamorph/CPopupMenuDecorator.java 2010-02-01 23:16:02.000000000 +0900
@@ -95,10 +95,8 @@
new JRadioButtonMenuItem("Edit polygon.");
/** Edit configuration command. */
private JMenuItem m_edit_config = new JMenuItem("Edit Config ->");
- /** Open the help PDF viewer. */
- private JMenuItem m_help = new JMenuItem("Help?");
/** Show about box command. */
- private JMenuItem m_about = new JMenuItem("About?");
+ private JMenuItem m_about = new JMenuItem("Help about?");
/**
* Constructor.
* @param parent The parent JComponent to draw the mouse symbol to.
@@ -115,7 +113,6 @@
popup_menu.add(this.mesh_menu);
popup_menu.add(this.polygon_menu);
popup_menu.addSeparator();
- popup_menu.add(m_help);
popup_menu.add(m_about);
mesh_menu.add(m_add_mesh_points);
mesh_menu.add(m_sub_mesh_points);
@@ -146,7 +143,6 @@
m_sub_polygon_points.addActionListener(this);
m_off_polygon_points.addActionListener(this);
m_delete_polygon.addActionListener(this);
- m_help.addActionListener(this);
m_about.addActionListener(this);
parent.addMouseListener(this);
}
@@ -230,24 +226,10 @@
if(m_edit_config == e.getSource()){
parent.getParent().showConfigDialog();
}
- if(m_help == e.getSource()){
- try{
- String cmd =
- System.getProperty("HELPVIEW") +
- ' ' +
- System.getProperty("HELPFILE");
- System.out.println("Try call " + cmd + ' ');
- Runtime.getRuntime().exec(cmd);
- }catch(Exception x){
- JOptionPane.showMessageDialog
- (parent, "Helpfile missing. Download \"JavaMorph.pdf!\"");
- System.out.println(x.getMessage());
- x.printStackTrace();
- }
- }
if(m_about == e.getSource()){
parent.getParent().showAboutDialog();
}
+
if(m_add_mesh_points == e.getSource()){
CConfig.edit_state = CConfig.EDIT_MESH_ADD;
}
diff -Nru javamorph-0.0.20100201/javamorph.1 javamorph-0.0.20100201/javamorph.1
--- javamorph-0.0.20100201/javamorph.1 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/javamorph.1 1970-01-01 09:00:00.000000000 +0900
@@ -1,42 +0,0 @@
-.\" Hey, EMACS: -*- nroff -*-
-.\" First parameter, NAME, should be all caps
-.\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
-.\" other parameters are allowed: see man(7), man(1)
-.TH "JAVAMORPH" "1" "January 9, 2010"
-.\" Please adjust this date whenever revising the manpage.
-.\"
-.\" Some roff macros, for reference:
-.\" .nh disable hyphenation
-.\" .hy enable hyphenation
-.\" .ad l left justify
-.\" .ad b justify to both left and right margins
-.\" .nf disable filling
-.\" .fi enable filling
-.\" .br insert line break
-.\" .sp <n> insert n+1 empty lines
-.\" for manpage-specific macros, see man(7)
-.SH NAME
-javamorph \- Make a morphing film between two pictures of human faces (GUI).
-.SH SYNOPSIS
-.B javamorph
-.SH DESCRIPTION
-\fBjavamorph\fP merges its two input pictures to a film-like sequence of
-bitmaps where the left picture morphs to the right one. Feel free to convert
-the picture sequence into a MPEG stream by using tools like MENCODER! Morphing
-is done by this program in a half automatic way, the user has to mark
-characteristic regions by points.
-.SH OPTIONS
-This program doesn't have any command line options.
-.SH SEE ALSO
-\fBgimp\fP, \fBmplayer\fP, \fBjava\fP
-.br
-.SH FILES
-Help: \fB/usr/share/doc/javamorph/JavaMorph.pdf\fP
-.br
-Workdir: \fB$HOME/JavaMorph/\fP
-.SH AUTHOR
-javamorph was written by Claus Wimmer <[email protected]>.
-.PP
-This manual page was written by Claus Wimmer <[email protected]>,
-for the Debian project (and may be used by others).
-
diff -Nru javamorph-0.0.20100201/javamorph.desktop javamorph-0.0.20100201/javamorph.desktop
--- javamorph-0.0.20100201/javamorph.desktop 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/javamorph.desktop 1970-01-01 09:00:00.000000000 +0900
@@ -1,11 +0,0 @@
-[Desktop Entry]
-Version=0.0
-Name=JavaMorph
-Exec=/usr/bin/javamorph
-Terminal=false
-Icon=/usr/share/pixmaps/JavaMorph.xpm
-Type=Application
-MimeType=application/x-javamorph
-Categories=Graphics;
-GenericName=JavaMorph
-Comment=Merge two human-face-JPEGs!
diff -Nru javamorph-0.0.20100201/javamorph/CStrings.java javamorph-0.0.20100201/javamorph/CStrings.java
--- javamorph-0.0.20100201/javamorph/CStrings.java 2012-01-04 21:42:38.000000000 +0900
+++ javamorph-0.0.20100201/javamorph/CStrings.java 2010-02-01 23:44:22.000000000 +0900
@@ -44,7 +44,7 @@
/** Dir from which this application has been started. */
public static final String DIR = System.getProperty("user.dir");
/** Location of the .jar distribution file. */
- public static final String JAR = DIR + SEP + "JavaMorph_2010_02_01.jar";
+ public static final String JAR = DIR + SEP + "JavaMorph_2009_01_19.jar";
/** Program name. */
public static final String PROG = "JavaMorph";
/** Program version. */
@@ -54,13 +54,15 @@
/** License description. */
public static final String LICENSE = "GPLv2";
/** Working directory name. */
- public static final String APPDIR = PROG + SEP;
+ public static final String APPDIR = "Desktop" + SEP + PROG + SEP;
/** Working directory path. */
public static final String WORKDIR = HOME + APPDIR;
/** Input directory path. */
public static final String INPUTDIR = HOME + APPDIR + "input" + SEP;
/** Debug directory path. */
public static final String DEBUGDIR = HOME + APPDIR + "debug" + SEP;
+ /** Help directory path. */
+ public static final String HELPDIR = HOME + APPDIR + "help" + SEP;
/** Polygon data directory path. */
public static final String POLYGONDIR = HOME + APPDIR + "polygon" + SEP;
/** Mesh data directory path. */
@@ -85,8 +87,10 @@
public static final String LEFT_DEBUG = DEBUGDIR + "left_debug.png";
/** Right clip matrix file name & path. */
public static final String RIGHT_DEBUG = DEBUGDIR + "right_debug.png";
- /** Help directory path. */
- public static final String HELPDIR = System.getProperty("HELPDIR");
+ /** Copyright file name & path. */
+ public static final String COPYING = HELPDIR + "COPYING";
+ /** Help file name & path. */
+ public static final String HELP = HELPDIR + "JavaMorph.pdf";
/** File to store the triangulation of the left mesh to. */
public static final String LEFT_TRI = DEBUGDIR + "t_left_triangles.png";
/** File to store the triangulation of the right mesh to. */
@@ -163,6 +167,8 @@
* sub directories of the working directory.
*/
public static void extractFiles(){
+ copyFile("help/COPYING", COPYING);
+ copyFile("help/JavaMorph.pdf", HELP);
copyFile("input/left.jpg", LEFT_INPUT);
copyFile("input/right.jpg", RIGHT_INPUT);
copyFile("mesh/left.msh", LEFT_MESH);